@@ -4,6 +4,28 @@ data_dir <- base_path
 base_path <- tempdir()
 data_dir <- "."
 
+cls <- read.table(header = TRUE, text = '
+Name Sex Age Height Weight    region
+Alfred   M  14   69.0  112.5   A
+Alice   F  13   56.5   84.0    A
+Barbara   F  13   65.3   98.0  A
+Carol   F  14   62.8  102.5    A
+Henry   M  14   63.5  102.5    A
+James   M  12   57.3   83.0    A
+Jane   F  12   59.8   84.5     A
+Janet   F  15   62.5  112.5    A
+Jeffrey   M  13   62.5   84.0  A
+John   M  12   59.0   99.5     B
+Joyce   F  11   51.3   50.5    B
+Judy   F  14   64.3   90.0     B
+Louise   F  12   56.3   77.0   B
+Mary   F  15   66.5  112.0     B
+Philip   M  16   72.0  150.0   B
+Robert   M  12   64.8  128.0   B
+Ronald   M  15   67.0  133.0   B
+Thomas   M  11   57.5   85.0   B
+William   M  15   66.5  112.0  B')
+
 dev <- FALSE
 
 
@@ -690,3 +712,72 @@ test_that("utils21: get_formulas() works as expected.", {
   expect_equal("formula" %in% class(res[[2]]), TRUE)
 
 })
+
+
+test_that("utils22: get_vars() works as expected.", {
+
+
+  myfm <- formula(Weight ~ Height + Sex + BMI)
+
+  res <- get_vars(myfm)
+
+  res
+
+  expect_equal(res$dvar, "Weight")
+  expect_equal(res$ivar, c("Height", "Sex", "BMI"))
+
+  myfm <- formula(Weight ~ Height)
+
+  res <- get_vars(myfm)
+
+  res
+
+  expect_equal(res$dvar, "Weight")
+  expect_equal(res$ivar, c("Height"))
+
+})
+
+
+test_that("utils23: get_obs() works as expected.", {
+
+
+  myfm <- formula(Weight ~ Height + Age)
+
+  cls2 <- cls
+
+  cls2[5, "Age"] <- NA
+  cls2[7, "Height"] <- NA
+  cls2[11, "Weight"] <- NA
+  cls2[17, "Age"] <- NA
+  cls2[17, "Height"] <- NA
+
+  cls2
+
+
+  res <- get_obs(cls2, myfm)
+
+  res
+
+  expect_equal(res$NOBS[1], 19)
+  expect_equal(res$NOBS[2], 15)
+  expect_equal(res$NOBS[3], 4)
+
+})
+
+test_that("utils23: get_valid_obs() works as expected.", {
+
+
+  myfm <- formula(Weight ~ Height + Age)
+
+  cls2 <- cls
+
+  cls2[2, "Weight"] <- NA
+  cls2[5, "Age"] <- NA
+  cls2[11, "Height"] <- NA
+
+  res1 <- get_valid_obs(cls2, myfm)
+
+  expect_equal(nrow(cls), 19)
+  expect_equal(nrow(res1), 16)
+
+})
